@@ -4,7 +4,7 @@
 #
 # Duplicity is free software; you can redistribute it and/or modify it
 # under the terms of the GNU General Public License as published by the
-# Free Software Foundation; either version 2 of the License, or (at your
+# Free Software Foundation; either version 3 of the License, or (at your
 # option) any later version.
 #
 # Duplicity is distributed in the hope that it will be useful, but
@@ -120,14 +120,11 @@ class BackupSet:
 			local_manifest = self.get_local_manifest()
 		if remote_manifest and self.local_manifest_path and local_manifest:
 			if remote_manifest != local_manifest:
-				log.FatalError(
-"""Fatal Error: Remote manifest does not match local one.  Either the
-remote backup set or the local archive directory has been corrupted.""")
-
+				log.FatalError("Fatal Error: Remote manifest does not match local one.  Either the "
+							   "remote backup set or the local archive directory has been corrupted.")
 		if not remote_manifest:
-			if local_manifest: remote_manifest = local_manifest
-			else: log.FatalError("Fatal Error: Neither remote nor "
-								 "local manifest readable.")
+			if self.local_manifest_path: remote_manifest = local_manifest
+			else: log.FatalError("Fatal Error: Neither remote nor local manifest is readable.")
 		remote_manifest.check_dirinfo()
 
 	def get_local_manifest(self):
@@ -200,10 +197,23 @@ class BackupChain:
 		"""Add incset to self.  Return None if incset does not match"""
 		if self.end_time == incset.start_time:
 			self.incset_list.append(incset)
-			self.end_time = incset.end_time
-			assert self.end_time
-			return 1
-		else: return None
+		else:
+			if (self.incset_list
+				and incset.start_time == self.incset_list[-1].start_time
+				and incset.end_time > self.incset_list[-1]):
+				log.Log("Preferring Backupset over previous one!", 8)
+				self.incset_list[-1] = incset
+			else:
+				log.Log("Ignoring incremental Backupset (start_time: %s; needed: %s)" %
+						(dup_time.timetopretty(incset.start_time),
+						 dup_time.timetopretty(self.end_time)), 8)
+				return None
+		self.end_time = incset.end_time
+		log.Log("Added incremental Backupset (start_time: %s / end_time: %s)" %
+				(dup_time.timetopretty(incset.start_time),
+				 dup_time.timetopretty(incset.end_time)), 8)
+		assert self.end_time
+		return 1
 
 	def delete(self):
 		"""Delete all sets in chain, in reverse order"""
@@ -323,8 +333,8 @@ class SignatureChain:
 		# Try to delete in opposite order, so something useful even if aborted
 		if self.archive_dir:
 			for i in range(len(self.inclist)-1, -1, -1):
-				self.inclist[i].delete()
-			self.fullsig.delete()
+				self.archive_dir.append(self.inclist[i]).delete()       
+			self.archive_dir.append(self.fullsig).delete()
 		else:
 			assert self.backend
 			inclist_copy = self.inclist[:]
@@ -441,13 +451,24 @@ class CollectionsStatus:
 			sig_chains = self.get_sorted_chains(sig_chains)
 			for i in range(len(sig_chains)-1, -1, -1):
 				if sig_chains[i].end_time == latest_backup_chain.end_time:
-					if self.matched_chain_pair == None:
-						self.matched_chain_pair = (sig_chains[i],
-												   backup_chains[-1])
-					
-					del sig_chains[i]
-					# break     # MDR this way the remote will not be
-					            # deleted if local present
+					pass
+				# See if the set before last matches:
+				elif (len(latest_backup_chain.get_all_sets()) >= 2 and
+					  sig_chains[i].end_time == latest_backup_chain.get_all_sets()[-2].end_time):
+						# It matches, remove the last backup set:
+						log.Warn("Warning, discarding last backup set, because of missing signature file.")
+						self.incomplete_backup_sets.append(latest_backup_chain.incset_list[-1])
+						latest_backup_chain.incset_list = latest_backup_chain.incset_list[:-1]
+				else: continue
+
+				# Found a matching pair:
+				if self.matched_chain_pair == None:
+					self.matched_chain_pair = (sig_chains[i], latest_backup_chain)
+				
+				del sig_chains[i]
+				# break     # MDR this way the remote will not be
+					    # deleted if local present
+							
 		if self.matched_chain_pair:
 			self.other_sig_chains.remove(self.matched_chain_pair[0])
 			self.other_backup_chains.remove(self.matched_chain_pair[1])
