@@ -37,13 +37,13 @@
 """Read from and write to tar format archives.
 """
 
-__version__ = "$Revision: 1.4 $"
-# $Source: /cvsroot/duplicity/duplicity/duplicity/tarfile.py,v $
+__version__ = "$Revision: 1.6 $"
+# $Source: /sources/duplicity/duplicity/duplicity/tarfile.py,v $
 
 version     = "0.4.9"
 __author__  = "Lars Gustabel (lars@gustaebel.de)"
-__date__    = "$Date: 2003/08/10 01:05:17 $"
-__cvsid__   = "$Id: tarfile.py,v 1.4 2003/08/10 01:05:17 bescoto Exp $"
+__date__    = "$Date: 2007/05/30 00:30:57 $"
+__cvsid__   = "$Id: tarfile.py,v 1.6 2007/05/30 00:30:57 loafman Exp $"
 __credits__ = "Gustavo Niemeyer for his support, " \
               "Detlef Lannert for some early contributions"
 
@@ -385,6 +385,12 @@ class TarInfo:
     def getheader(self):
         """Return a tar header block as a 512 byte string.
         """
+        if self.uid > 2097151 or self.uid < 0:
+            sys.stderr.write("uid %i of file %s not in range. Setting uid to 60001\n" % (self.uid,self.name))
+            self.uid = 60001
+        if self.gid > 2097151 or self.gid < 0:
+            sys.stderr.write("gid %i of file %s not in range. Setting gid to 60001\n" % (self.gid, self.name))
+            self.gid = 60001
         # The following code was contributed by Detlef Lannert.
         parts = []
         for value, fieldsize in (
@@ -1056,12 +1062,14 @@ class TarFile:
         """
         tarinfo = TarInfo()
         tarinfo.name = nts(buf[0:100])
-        tarinfo.mode = int(buf[100:108], 8)
-        tarinfo.uid = int(buf[108:116],8)
-        tarinfo.gid = int(buf[116:124],8)
-        tarinfo.size = long(buf[124:136], 8)
-        tarinfo.mtime = long(buf[136:148], 8)
-        tarinfo.chksum = int(buf[148:156], 8)
+        tarinfo.mode = int(buf[100:107], 8)
+        tarinfo.uid = int(buf[108:115],8)
+        tarinfo.gid = int(buf[116:123],8)
+        tarinfo.size = long(buf[124:135], 8)
+        tarinfo.mtime = long(buf[136:147], 8)
+		# chksum stored as a six digit octal number with
+		# leading zeroes followed by a nul and then a space
+        tarinfo.chksum = int(buf[148:154], 8)
         tarinfo.type = buf[156:157]
         tarinfo.linkname = nts(buf[157:257])
         tarinfo.uname = nts(buf[265:297])
